@@ -13,6 +13,7 @@ Reproduction or distribution, in whole or in part, is forbidden except by expres
 import datetime
 import hashlib
 import requests
+import json
 
 from ReversingLabs.SDK.helper import ADVANCED_SEARCH_SORTING_CRITERIA, DEFAULT_USER_AGENT, HASH_LENGTH_MAP, \
     RESPONSE_CODE_ERROR_MAP, \
@@ -50,7 +51,8 @@ class TiCloudAPI(object):
                  user_agent=DEFAULT_USER_AGENT, allow_none_return=False):
 
         if host.startswith("http://"):
-            raise WrongInputError("Unsupported protocol definition: TitaniumCloud services can only be used over HTTPS.")
+            raise WrongInputError("Unsupported protocol definition: "
+                                  "TitaniumCloud services can only be used over HTTPS.")
         self._host = self.__format_url(host)
 
         self._username = username
@@ -338,14 +340,14 @@ class FileAnalysis(TiCloudAPI):
         return response
 
     @staticmethod
-    def extract_uri_list_from_report(reports_dict):
-        """Return a list of all the URIs from a list of results (entries).
-            :param reports_dict: list of results (entries)
-            :type reports_dict: dict
+    def extract_uri_list_from_report(report_dict):
+        """Return a list of all the URIs from a file analysis report dictionary.
+            :param report_dict: file analysis report dictionary
+            :type report_dict: dict
             :return: list of uris
             :rtype: list
         """
-        if not isinstance(reports_dict, dict):
+        if not isinstance(report_dict, dict):
             raise WrongInputError("reports_dict parameter must be a dictionary.")
 
         sha1_key = SHA1
@@ -407,59 +409,67 @@ class FileAnalysis(TiCloudAPI):
 
         uris = []
 
-        for report in reports_dict:
-            for entry in report.get("analysis", {}).get("entries", []):
-                for interesting_string in entry.get("tc_report", {}).get("interesting_strings", []):
-                    for value in interesting_string['values']:
-                        uris.append({
-                            sha1_key: report[SHA1],
-                            from_key: "interesting_strings",
-                            category_key: interesting_string["category"],
-                            uri_key: value
-                        })
-
-                for property in entry.get("tc_report", {}).get("info", {}).get("package", {}).get("properties", []):
-                    if property.get("name", "").startswith("botServer"):
-                        uris.append({
-                            sha1_key: report[SHA1],
-                            from_key: "package",
-                            category_key: "uri",
-                            uri_key: property["value"]
-                        })
-
-            for entry in report.get("sources", {}).get("entries", []):
-                if "domain" in entry:
+        sample = report_dict.get("rl", {}).get("sample", {})
+        for entry in sample.get("analysis", {}).get("entries", []):
+            for interesting_string in entry.get("tc_report", {}).get("interesting_strings", []):
+                for value in interesting_string['values']:
                     uris.append({
-                        sha1_key: report[SHA1],
-                        from_key: "sources",
-                        category_key: "domain",
-                        uri_key: entry["domain"].get("name")
+                        sha1_key: sample[SHA1],
+                        from_key: "interesting_strings",
+                        category_key: interesting_string["category"],
+                        uri_key: value
                     })
-                for property in entry.get("properties", []):
-                    if property["name"] == "url" and property["value"] != '':
-                        uris.append({
-                            sha1_key: report[SHA1],
-                            from_key: "sources",
-                            category_key: "url",
-                            uri_key: property["value"]
-                        })
 
-            for entry in report.get("dynamic_analysis", {}).get("entries", []):
-                if "dynamic_analysis_report_joe_sandbox" in entry:
-                    reports_dict = entry["dynamic_analysis_report_joe_sandbox"]
-                    if "network" in reports_dict:
-                        uris.extend(network_uris(reports_dict["network"],
-                                                 "dynamic_analysis_report_joe_sandbox",
-                                                 report[SHA1]))
+            for property in entry.get("tc_report", {}).get("info", {}).get("package", {}).get("properties", []):
+                if property.get("name", "").startswith("botServer"):
+                    uris.append({
+                        sha1_key: sample[SHA1],
+                        from_key: "package",
+                        category_key: "uri",
+                        uri_key: property["value"]
+                    })
 
-                if "dynamic_analysis_report" in entry:
-                    reports_dict = entry["dynamic_analysis_report"]
-                    if "network" in reports_dict:
-                        uris.extend(network_uris(reports_dict["network"],
-                                                 "dynamic_analysis_report",
-                                                 report[SHA1]))
+        for entry in sample.get("sources", {}).get("entries", []):
+            if "domain" in entry:
+                uris.append({
+                    sha1_key: sample[SHA1],
+                    from_key: "sources",
+                    category_key: "domain",
+                    uri_key: entry["domain"].get("name")
+                })
+            for property in entry.get("properties", []):
+                if property["name"] == "url" and property["value"] != '':
+                    uris.append({
+                        sha1_key: sample[SHA1],
+                        from_key: "sources",
+                        category_key: "url",
+                        uri_key: property["value"]
+                    })
 
-        deduplicated_uris = list(set(uris))
+        for entry in sample.get("dynamic_analysis", {}).get("entries", []):
+            if "dynamic_analysis_report_joe_sandbox" in entry:
+                report_dict = entry["dynamic_analysis_report_joe_sandbox"]
+                if "network" in report_dict:
+                    uris.extend(network_uris(report_dict["network"],
+                                             "dynamic_analysis_report_joe_sandbox",
+                                             sample[SHA1]))
+
+            if "dynamic_analysis_report" in entry:
+                report_dict = entry["dynamic_analysis_report"]
+                if "network" in report_dict:
+                    uris.extend(network_uris(report_dict["network"],
+                                             "dynamic_analysis_report",
+                                             sample[SHA1]))
+
+        transitional_dict = {}
+        for item in uris:
+            item_str = json.dumps(item)
+            transitional_dict[item_str] = item_str
+
+        deduplicated_uris = []
+        for key, _ in transitional_dict.items():
+            item = json.loads(key)
+            deduplicated_uris.append(item)
 
         return deduplicated_uris
 
@@ -694,7 +704,7 @@ class RHA1Analytics(TiCloudAPI):
             )
 
             post_json = {"rl": {"query": {"rha1_type": rha1_type, "response_format": "json",
-                                "extended": extended_results, "hashes": hash_input}}}
+                                          "extended": extended_results, "hashes": hash_input}}}
 
             response = self._post_request(url=url, post_json=post_json)
 
@@ -1540,7 +1550,7 @@ def _update_hash_object(input_source, hash_object):
         :param input_source: open file in "rb" mode or string
         :type input_source: str or file or BinaryIO
         :param hash_object: hash object
-        :type hash_object: _hashlib.HASH
+        :type hash_object: _hashlib._HASH
         :returns: updated hash object
         :rtype: _hashlib.HASH
     """
